import NormalButton from '@/components/normalButton'
import Popup from '@/components/popup'
import { View } from '@tarojs/components'
import classnames from 'classnames'
import styles from './index.module.scss'
import React, { FC, memo, useEffect, useState } from 'react'
import Search from '@/components/search'
import IconFont from '@/components/iconfont/iconfont'
import { EnumDeliveryNoticeTypeList } from '@/api/index'
import dayjs from 'dayjs'

type SearchFilter = {
  type?: number
  timeKey?: string
}

const scanIcon = () => {
  // 扫描
  const handleScan = () => {}
  return (
    <View onClick={handleScan} className={styles.scanHandler}>
      <IconFont name='icon-saomiao' size={40}></IconFont>
    </View>
  )
}

const DeliveryFilter: FC = memo(() => {
  const { fetchData } = EnumDeliveryNoticeTypeList()

  const [searchFilter, setSearchFilter] = useState<SearchFilter>({
    type: undefined,
    timeKey: '0',
  })
  const handleSelectedType = (type: string | number) => {
    console.log('type==>', type)
    if (typeof type === 'string' && type === 'default') {
      setSearchFilter((e) => ({ ...e, type: undefined }))
    } else {
      setSearchFilter((e) => ({ ...e, type: type as number }))
    }
  }

  const handleSearchBarChange = () => {}

  useEffect(() => {
    getEnumData()
  }, [])

  const [typeList, setTypeList] = useState<{ id: number; name: string }[]>()

  const getEnumData = async () => {
    const res = await fetchData()
    setTypeList(res.data.list)
  }

  const [customTime, setCustomTime] = useState({
    date_min: undefined,
    date_max: undefined,
  })

  const filterTimeOptions = {
    0: {
      name: '不限',
      date_min: undefined,
      date_max: undefined,
    },
    1: {
      name: '今天',
      date_min: `${dayjs(new Date()).add(0, 'day').format('YYYY-MM-DD')} 00:00:00`,
      date_max: `${dayjs(new Date()).add(1, 'day').format('YYYY-MM-DD')} 00:00:00`,
    },
    2: {
      name: '昨日',
      date_min: `${dayjs(new Date()).add(0, 'day').format('YYYY-MM-DD')} 00:00:00`,
      date_max: `${dayjs(new Date()).add(-1, 'day').format('YYYY-MM-DD')} 00:00:00`,
    },
    3: {
      name: '近7日',
      date_min: `${dayjs(new Date()).add(0, 'day').format('YYYY-MM-DD')} 00:00:00`,
      date_max: `${dayjs(new Date()).add(-7, 'day').format('YYYY-MM-DD')} 00:00:00`,
    },
    4: {
      name: '近30日',
      date_min: `${dayjs(new Date()).add(0, 'day').format('YYYY-MM-DD')} 00:00:00`,
      date_max: `${dayjs(new Date()).add(-30, 'day').format('YYYY-MM-DD')} 00:00:00`,
    },
    5: {
      name: '近90日',
      date_min: `${dayjs(new Date()).add(0, 'day').format('YYYY-MM-DD')} 00:00:00`,
      date_max: `${dayjs(new Date()).add(-90, 'day').format('YYYY-MM-DD')} 00:00:00`,
    },
  }

  const handleSelectedTime = (timeOptionId) => {
    setSearchFilter((e) => ({ ...e, timeKey: timeOptionId }))
  }

  const handleReset = () => {}
  const handleConfirm = () => {}

  return (
    <>
      <View className={styles.filterItem}>
        <View className={styles['filterItem--title']}>发货类型</View>
        <View className={classnames(styles['filterItem--wrapper'], styles['filter--type'])}>
          <FilterButton isActive={searchFilter.type == undefined} onClick={() => handleSelectedType('default')}>
            不限
          </FilterButton>
          {!!typeList?.length &&
            typeList?.map((item) => {
              return (
                <FilterButton isActive={searchFilter.type === item?.id} onClick={() => handleSelectedType(item?.id)}>
                  {item.name}
                </FilterButton>
              )
            })}
        </View>
      </View>
      <View className={styles.filterItem}>
        <View className={styles['filterItem--title']}>发货单号</View>
        <View className={classnames(styles['filterItem--wrapper'], styles['filter--inputBar'])}>
          <Search
            placeholder='请输入或扫描条形码'
            showBtn={false}
            changeOnSearch={handleSearchBarChange}
            debounceTime={300}
            customRightSlot={scanIcon()}></Search>
        </View>
      </View>
      <View className={styles.filterItem}>
        <View className={styles['filterItem--title']}>查询日期</View>
        <View className={classnames(styles['filterItem--wrapper'], styles['filter--time'])}>
          {Object.entries(filterTimeOptions).map(([key, value]) => {
            return (
              <FilterButton isActive={searchFilter.timeKey === key} onClick={() => handleSelectedTime(key)}>
                {value.name}
              </FilterButton>
            )
          })}
          <FilterButton isActive={searchFilter.timeKey === '6'} customClassName={styles.filterTimeButton} onClick={() => handleSelectedTime('6')}>
            自定义时间<IconFont name='icon-chakanquanbukehu' size={40} color={searchFilter.timeKey === '6' ? '#4581ff' : '#909090'}></IconFont>
          </FilterButton>
        </View>
      </View>
      <View className={styles.filterController}>
        <NormalButton type='primary' round customClassName={classnames(styles.btn, styles.rest_btn)} onClick={handleReset}>
          重置
        </NormalButton>
        <NormalButton type='primary' plain round customClassName={classnames(styles.btn, styles.verify_btn)} onClick={handleConfirm}>
          确认
        </NormalButton>
      </View>
    </>
  )
})

interface PropsType {
  isActive: boolean
  onClick?: Function
  children?: React.ReactNode
  customClassName?: string
}

const FilterButton: FC<PropsType> = ({ onClick, children, isActive = false, customClassName }) => {
  const handleClick = () => {
    onClick?.()
  }
  return (
    <View className={classnames(styles.filterButton, isActive && styles['filterButton--active'], customClassName)} onClick={handleClick}>
      <View className={classnames(styles['filterButton--text'])}>{children}</View>
    </View>
  )
}

export default DeliveryFilter
